"""Top-level package for inspire_info."""

__author__ = """Tim Wolf"""
__email__ = 'tim.wolf@mpi-hd.mpg.de'
__version__ = '0.1.9'

from .myutils import *
from .LatexCreator import *
from .Author import *
from .Publication import *